# win32material
Apply some window effects like `mica` `micaalt` `acrylic` to the Win32 Applications.
Can also change the window's titlebar color, border type and so on. (Windows 11 only)

## Installation
```console
pip install win32material --user
```

## Help
How to get the hwnd of the window?
```python
from ctypes import windll, c_char_p
hwnd = windll.user32.FindWindowW(c_char_p(None), "{Your window name}")
```

## Gallery
![image](https://github.com/littlewhitecloud/win32material/assets/71159641/ffcea60c-718a-4315-9069-c1e4abc3f4cd)
![image](https://github.com/littlewhitecloud/win32material/assets/71159641/c9e522c5-d8c5-4563-a0e5-7fef39366a1d)
![image](https://github.com/littlewhitecloud/win32style/assets/71159641/760b5195-354e-428c-9f48-781e7a4dc3ae)
```python
from win32material import ApplyMica, ApplyAcrylic

# ApplyMica(hwnd, theme, micaalt)
# ApplyAcrylic(hwnd, extend)
```

```python
ChangeTitlebarColor(hwnd, "#111111")
```
![image](https://github.com/littlewhitecloud/win32style/assets/71159641/bc179e80-fcb0-48e4-92f0-8ab9e465ef1e)

```python
ChangeBorderColor(hwnd, "#114514")
```
![image](https://github.com/littlewhitecloud/win32style/assets/71159641/7c3b035d-4a40-4026-aa5f-fbaf27846e43)


```python
ChangeTitleColor(hwnd, "#745616")
```
![image](https://github.com/littlewhitecloud/win32style/assets/71159641/f3521d0b-3483-4138-bcda-b2d742079385)

```python
SetBorderType(hwnd, BORDERTYPE.RECTANGULAR)
```
![image](https://github.com/littlewhitecloud/win32style/assets/71159641/2a609226-5021-47f5-a80e-0e9250701140)

```python
SetBorderType(hwnd, BORDERTYPE.ROUND)
```
![image](https://github.com/littlewhitecloud/win32style/assets/71159641/5648f581-3a92-4a3c-bd74-853d5f38677a)

```python
SetBorderType(hwnd, BORDERTYPE.SMALLROUND)
```
![image](https://github.com/littlewhitecloud/win32style/assets/71159641/f06c4917-757f-48c5-b411-ed243f8fdf1c)

### Thanks
Get the idea of applying mica from [https://github.com/marticliment/win32mica/](https://github.com/marticliment/win32mica/)
And some other ideas from [https://github.com/Akascape/py-win-styles](https://github.com/Akascape/py-window-styles)
